// Avoid including tut code
#define NOTESTS
#define INSTANTIATING_TEMPLATES

#include "Serializer.h"

#include <tagcoll/InputMerger.cc>
#include <tagcoll/ItemGrouper.cc>
#include <tagcoll/OpSet.cc>
#include <tagcoll/Patches.cc>
#include <tagcoll/Serializer.cc>
#include <tagcoll/TextFormat.cc>

using namespace Tagcoll;

// Instantiate standard tagcoll templates

template class OpSet<Tag>;
template class OpSet<Facet>;
template class Consumer<string, Tag>;
template class InputMerger<string, Tag>;
template class ItemGrouper<string, Tag>;
template class PatchList<string, Tag>;
template class Converter<string, Tag>;
template class Converter<Tag, string>;
template class TextFormat<string, Tag>;

/*
#include "TagcollDocument.h"
#include "TagcollDocument.cc"

template class TagcollDocument<string>;
*/

// vim:set ts=4 sw=4:
